from kpl_dataset import BasicType

RectangleBoxObjectDetectionDatasetDefine = {
    "path": BasicType.String,
    "content": BasicType.ByteArray,
    "contentType": BasicType.String,
    "object": [
        {"name": BasicType.String,
         "xmin": BasicType.Int,
         "xmax": BasicType.Int,
         "ymin": BasicType.Int,
         "ymax": BasicType.Int,
         "difficult": BasicType.Int,
         "score": BasicType.Float
         }
    ]
}

ClassificationDatasetDefine = {
    "path": BasicType.String,
    "content": BasicType.ByteArray,
    "contentType": BasicType.String,
    "class_name": BasicType.String,
    "class_id": BasicType.Int,
}



#!/usr/bin/env python
from setuptools import setup, find_packages


setup(name='kpl-dataset',
      version='0.0.5',
      platforms='any',
      description='KPL Dataset',
      packages=find_packages(),
      install_requires=[
          'protobuf==3.11.0'
      ],
      classifiers=[
          'Programming Language :: Python',
          'Operating System :: OS Independent',
      ])
